@@ -1,5 +1,3 @@
-#include "config.h"
-
 #include <sys/types.h>
 #include <sys/wait.h>
 #include <unistd.h>
@@ -19,7 +17,7 @@ find_dir_entry (XdgDirEntry *entries, const char *type)
   for (i = 0; entries[i].type != NULL; i++)
     {
       if (strcmp (entries[i].type, type) == 0)
-	return &entries[i];
+        return &entries[i];
     }
   return NULL;
 }
@@ -32,7 +30,7 @@ find_dir_entry_by_path (XdgDirEntry *entries, const char *path)
   for (i = 0; entries[i].type != NULL; i++)
     {
       if (strcmp (entries[i].path, path) == 0)
-	return &entries[i];
+        return &entries[i];
     }
   return NULL;
 }
@@ -106,7 +104,7 @@ update_locale (XdgDirEntry *old_entries)
     return;
   close (fd);
   
-  cmdline = g_strdup_printf (XDG_USER_DIRS_UPDATE " --force --dummy-output %s", filename);
+  cmdline = g_strdup_printf ("xdg-user-dirs-update --force --dummy-output %s", filename);
   if (!g_spawn_command_line_sync  (cmdline, &std_out, &std_err, &exit_status, NULL))
     {
       g_free (std_out);
@@ -131,47 +129,47 @@ update_locale (XdgDirEntry *old_entries)
   for (i = 0; old_entries[i].type != NULL; i++)
     {
       for (j = 0; new_entries[j].type != NULL; j++)
-	{
-	  if (strcmp (old_entries[i].type, new_entries[j].type) == 0)
-	    break;
-	}
+        {
+          if (strcmp (old_entries[i].type, new_entries[j].type) == 0)
+            break;
+        }
       if (new_entries[j].type != NULL &&
-	  strcmp (old_entries[i].path, new_entries[j].path) != 0)
-	{
-	  char *from, *to;
-	  from = g_filename_display_name (old_entries[i].path);
-	  to = g_filename_display_name (new_entries[j].path);
+          strcmp (old_entries[i].path, new_entries[j].path) != 0)
+        {
+          char *from, *to;
+          from = g_filename_display_name (old_entries[i].path);
+          to = g_filename_display_name (new_entries[j].path);
 
-	  gtk_list_store_append (list_store, &iter);
-	  gtk_list_store_set (list_store, &iter,
-			      0, from, 1, to, -1);
-	  
-	  g_free (from);
-	  g_free (to);
-	  
-	  has_changes = TRUE;
-	}
+          gtk_list_store_append (list_store, &iter);
+          gtk_list_store_set (list_store, &iter,
+                              0, from, 1, to, -1);
+          
+          g_free (from);
+          g_free (to);
+          
+          has_changes = TRUE;
+        }
     }
   for (j = 0; new_entries[j].type != NULL; j++)
     {
       for (i = 0; old_entries[i].type != NULL; i++)
-	{
-	  if (strcmp (old_entries[i].type, new_entries[j].type) == 0)
-	    break;
-	}
+        {
+          if (strcmp (old_entries[i].type, new_entries[j].type) == 0)
+            break;
+        }
       if (old_entries[i].type == NULL)
-	{
-	  char *to;
-	  to = g_filename_display_name (new_entries[j].path);
+        {
+          char *to;
+          to = g_filename_display_name (new_entries[j].path);
 
-	  gtk_list_store_append (list_store, &iter);
-	  gtk_list_store_set (list_store, &iter,
-			      0, "-", 1, to, -1);
+          gtk_list_store_append (list_store, &iter);
+          gtk_list_store_set (list_store, &iter,
+                              0, "-", 1, to, -1);
 
-	  g_free (to);
-	  
-	  has_changes = TRUE;
-	}
+          g_free (to);
+          
+          has_changes = TRUE;
+        }
     }
 
   if (!has_changes)
@@ -181,16 +179,16 @@ update_locale (XdgDirEntry *old_entries)
     }
   
   dialog = gtk_message_dialog_new (NULL, 0,
-				   GTK_MESSAGE_WARNING,
-				   GTK_BUTTONS_NONE,
-				   _("Update standard folders to current language?"));
+                                   GTK_MESSAGE_WARNING,
+                                   GTK_BUTTONS_NONE,
+                                   _("Update standard folders to current language?"));
   gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-					    _("You have logged in in a new language. You can automatically update the names of some standard folders in your home folder to match this language. The update would change the following folders:"));
+                                            _("You have logged in in a new language. You can automatically update the names of some standard folders in your home folder to match this language. The update would change the following folders:"));
 
   gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-			  _("_Keep Old Names"), GTK_RESPONSE_NO,
-			  _("_Update Names"), GTK_RESPONSE_YES,
-			  NULL);
+                          _("_Keep Old Names"), GTK_RESPONSE_NO,
+                          _("_Update Names"), GTK_RESPONSE_YES,
+                          NULL);
 
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_NO);
 
@@ -201,10 +199,10 @@ update_locale (XdgDirEntry *old_entries)
 
   scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow),
-				  GTK_POLICY_NEVER,
-				  GTK_POLICY_NEVER);
+                                  GTK_POLICY_NEVER,
+                                  GTK_POLICY_NEVER);
   gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow),
-				       GTK_SHADOW_IN);  
+                                       GTK_SHADOW_IN);  
   
   gtk_box_pack_start (GTK_BOX (vbox), scrolledwindow, TRUE, TRUE, 0);
   
@@ -215,18 +213,18 @@ update_locale (XdgDirEntry *old_entries)
 
   cell = gtk_cell_renderer_text_new ();
   gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (treeview),
-					       -1, _("Current folder name"),
-					       cell,
-					       "text", 0,
-					       NULL);
+                                               -1, _("Current folder name"),
+                                               cell,
+                                               "text", 0,
+                                               NULL);
   gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (treeview),
-					       -1, _("New folder name"),
-					       cell,
-					       "text", 1,
-					       NULL);
+                                               -1, _("New folder name"),
+                                               cell,
+                                               "text", 1,
+                                               NULL);
 
   gtk_container_add (GTK_CONTAINER (scrolledwindow),
-		     treeview);
+                     treeview);
 
   gtk_widget_show_all (scrolledwindow);
 
@@ -245,38 +243,38 @@ update_locale (XdgDirEntry *old_entries)
 
   if (response == GTK_RESPONSE_YES)
     {
-      if (!g_spawn_command_line_sync (XDG_USER_DIRS_UPDATE " --force", NULL, NULL, &exit_status, NULL) ||
-	  !WIFEXITED(exit_status) ||
-	  WEXITSTATUS(exit_status) != 0)
-	{
-	  GtkWidget *error;
+      if (!g_spawn_command_line_sync ("xdg-user-dirs-update --force", NULL, NULL, &exit_status, NULL) ||
+          !WIFEXITED(exit_status) ||
+          WEXITSTATUS(exit_status) != 0)
+        {
+          GtkWidget *error;
 
-	  error = gtk_message_dialog_new (NULL, 0,
-					  GTK_MESSAGE_ERROR,
-					  GTK_BUTTONS_OK,
-					  _("There was an error updating the folders"));
-	  
-	  gtk_dialog_run (GTK_DIALOG (error));
-	  gtk_widget_destroy (error);
-	}
+          error = gtk_message_dialog_new (NULL, 0,
+                                          GTK_MESSAGE_ERROR,
+                                          GTK_BUTTONS_OK,
+                                          _("There was an error updating the folders"));
+          
+          gtk_dialog_run (GTK_DIALOG (error));
+          gtk_widget_destroy (error);
+        }
       else
-	{
-	  /* Change succeeded, remove any leftover empty directories */
-	  for (i = 0; old_entries[i].type != NULL; i++)
-	    {
-	      /* Never remove homedir */
-	      if (strcmp (old_entries[i].path, g_get_home_dir ()) == 0)
-		continue;
-	      
-	      /* If the old path is used by the new config, don't remove */
-	      entry = find_dir_entry_by_path (new_entries, old_entries[i].path);
-	      if (entry)
-		continue;
+        {
+          /* Change succeeded, remove any leftover empty directories */
+          for (i = 0; old_entries[i].type != NULL; i++)
+            {
+              /* Never remove homedir */
+              if (strcmp (old_entries[i].path, g_get_home_dir ()) == 0)
+                continue;
+              
+              /* If the old path is used by the new config, don't remove */
+              entry = find_dir_entry_by_path (new_entries, old_entries[i].path);
+              if (entry)
+                continue;
 
-	      /* Remove the dir, will fail if not empty */
-	      g_rmdir (old_entries[i].path);
-	    }
-	}
+              /* Remove the dir, will fail if not empty */
+              g_rmdir (old_entries[i].path);
+            }
+        }
     }
 
   if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check)))
@@ -321,6 +319,7 @@ main (int argc, char *argv[])
       strcmp (old_locale, locale) != 0 &&
       has_xdg_translation ())
     {
+       g_set_prgname ("user-dirs-update-gtk");
        gtk_init (&argc, &argv);
        update_locale (old_entries);
     }
@@ -333,64 +332,64 @@ main (int argc, char *argv[])
   if (bookmarks == NULL)
     {
       char *make_bm_for[] = {
-	"DOCUMENTS",
-	"MUSIC",
-	"PICTURES",
-	"VIDEOS",
-	"DOWNLOAD",
-	NULL};
+        "DOCUMENTS",
+        "MUSIC",
+        "PICTURES",
+        "VIDEOS",
+        "DOWNLOAD",
+        NULL};
       /* No previous bookmarks. Generate standard ones */
 
       desktop_entry = find_dir_entry (new_entries, "DESKTOP");
       for (i = 0; make_bm_for[i] != NULL; i++)
-	{
-	  entry = find_dir_entry (new_entries, make_bm_for[i]);
-	  
-	  if (entry && strcmp (entry->path, g_get_home_dir ()) != 0 &&
-	      (desktop_entry == NULL || strcmp (entry->path, desktop_entry->path) != 0))
-	    {
-	      uri = g_filename_to_uri (entry->path, NULL, NULL);
-	      if (uri)
-		{
-		  modified_bookmarks = TRUE;
-		  bookmark = g_new0 (GtkBookmark, 1);
-		  bookmark->uri = uri;
-		  bookmarks = g_list_append (bookmarks, bookmark);
-		}
-	    }
-	}
+        {
+          entry = find_dir_entry (new_entries, make_bm_for[i]);
+          
+          if (entry && strcmp (entry->path, g_get_home_dir ()) != 0 &&
+              (desktop_entry == NULL || strcmp (entry->path, desktop_entry->path) != 0))
+            {
+              uri = g_filename_to_uri (entry->path, NULL, NULL);
+              if (uri)
+                {
+                  modified_bookmarks = TRUE;
+                  bookmark = g_new0 (GtkBookmark, 1);
+                  bookmark->uri = uri;
+                  bookmarks = g_list_append (bookmarks, bookmark);
+                }
+            }
+        }
     }
   else
     {
       /* Map old bookmarks that were moved */
 
       for (l = bookmarks; l != NULL; l = l->next)
-	{
-	  char *path;
-	  
-	  bookmark = l->data;
+        {
+          char *path;
+          
+          bookmark = l->data;
 
-	  path = g_filename_from_uri (bookmark->uri, NULL, NULL);
-	  if (path)
-	    {
-	      entry = find_dir_entry_by_path (old_entries, path);
-	      if (entry)
-		{
-		  entry = find_dir_entry (new_entries, entry->type);
-		  if (entry)
-		    {
-		      uri = g_filename_to_uri (entry->path, NULL, NULL);
-		      if (uri)
-			{
-			  modified_bookmarks = TRUE;
-			  g_free (bookmark->uri);
-			  bookmark->uri = uri;
-			}
-		    }
-		}
-	      g_free (path);
-	    }
-	}
+          path = g_filename_from_uri (bookmark->uri, NULL, NULL);
+          if (path)
+            {
+              entry = find_dir_entry_by_path (old_entries, path);
+              if (entry)
+                {
+                  entry = find_dir_entry (new_entries, entry->type);
+                  if (entry)
+                    {
+                      uri = g_filename_to_uri (entry->path, NULL, NULL);
+                      if (uri)
+                        {
+                          modified_bookmarks = TRUE;
+                          g_free (bookmark->uri);
+                          bookmark->uri = uri;
+                        }
+                    }
+                }
+              g_free (path);
+            }
+        }
     }
 
   if (modified_bookmarks)
